@@ -8,12 +8,10 @@ functiondir="TOREPLACE_FUNCTION_DIR"
 functionname="TOREPLACE_FUNCTION_NAME"
 functionargs="TOREPLACE_FUNCTION_ARGS"
 
-echo $functionargs
-
 libmwmclmcrrt=v${runtimever::${#runtimever}-2}${runtimever:(-1)}
 MCRver=MCR_${matlabver}_glnxa64
 
-chmod u+x ${functiondir}/files/bin/run_${functionname}.sh
-chmod u+x ${functiondir}/files/bin/${functionname}
-${functiondir}/files/bin/./run_${functionname}.sh ${installationdir}/$MCRver/$libmwmclmcrrt $functionargs
+chmod u+x ${functiondir}/run_${functionname}.sh
+chmod u+x ${functiondir}/${functionname}
+${functiondir}/./run_${functionname}.sh ${installationdir}/$MCRver/$libmwmclmcrrt $functionargs
 
